Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(891)

Unified Diff: webkit/blob/blob_url_request_job.h

Issue 10447083: Rename webkit_blob::FileReader to FileStreamReader. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: merge master branch. Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | webkit/blob/blob_url_request_job.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/blob/blob_url_request_job.h
diff --git a/webkit/blob/blob_url_request_job.h b/webkit/blob/blob_url_request_job.h
index 436d0a9639e903d2509a57e83ee5960f4cc06956..676ebaf88d47d4b72dce7a890af5ce5ab98ef23b 100644
--- a/webkit/blob/blob_url_request_job.h
+++ b/webkit/blob/blob_url_request_job.h
@@ -20,13 +20,12 @@ struct PlatformFileInfo;
namespace net {
class DrainableIOBuffer;
-class FileStream;
class IOBuffer;
}
namespace webkit_blob {
-class LocalFileReader;
+class LocalFileStreamReader;
// A request job that handles reading blob URLs.
class BLOB_EXPORT BlobURLRequestJob : public net::URLRequestJob {
@@ -51,7 +50,7 @@ class BLOB_EXPORT BlobURLRequestJob : public net::URLRequestJob {
virtual ~BlobURLRequestJob();
private:
- typedef std::map<size_t, LocalFileReader*> IndexToReaderMap;
+ typedef std::map<size_t, LocalFileStreamReader*> IndexToReaderMap;
// For preparing for read: get the size, apply the range and perform seek.
void DidStart();
@@ -66,7 +65,7 @@ class BLOB_EXPORT BlobURLRequestJob : public net::URLRequestJob {
void AdvanceItem();
void AdvanceBytesRead(int result);
bool ReadBytesItem(const BlobData::Item& item, int bytes_to_read);
- bool ReadFileItem(LocalFileReader* reader, int bytes_to_read);
+ bool ReadFileItem(LocalFileStreamReader* reader, int bytes_to_read);
void DidReadFile(int result);
void DeleteCurrentFileReader();
@@ -78,9 +77,9 @@ class BLOB_EXPORT BlobURLRequestJob : public net::URLRequestJob {
void NotifyFailure(int);
void HeadersCompleted(int status_code, const std::string& status_txt);
// Returns a LocalFileReader for a blob item at |index|.
// If the item at |index| is not of TYPE_FILE this returns NULL.
- LocalFileReader* GetFileReader(size_t index);
+ LocalFileStreamReader* GetFileStreamReader(size_t index);
base::WeakPtrFactory<BlobURLRequestJob> weak_factory_;
scoped_refptr<BlobData> blob_data_;
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | webkit/blob/blob_url_request_job.cc » ('j') | no next file with comments »
@@ -78,9 +77,9 @@ class BLOB_EXPORT BlobURLRequestJob : public net::URLRequestJob {
void NotifyFailure(int);
void HeadersCompleted(int status_code, const std::string& status_txt);
- // Returns a LocalFileReader for a blob item at |index|.
+ // Returns a LocalFileStreamReader for a blob item at |index|.
// If the item at |index| is not of TYPE_FILE this returns NULL.

Powered by Google App Engine
This is Rietveld 408576698